<?php
// class returning frontend code for a single FAQ

class fr_front_faq_code_class {
	
	private $faq_id;
	private $faq_type;	// (string) whether FAQ is choice-based or basic
	private $choices; 	// JSON string containing the choises array
	
	private $choices_wrap_up = array(); // array the complete list of choices without parental tree
	
	private $imgs_wrap_up 	= array(); 	// array containing image urls involved in FAQ choices array('img_id' => array('thumb', 'full'))
	private $involved_imgs 	= array();
	private $first_img_id 	= false; 	// (bool|int) first gallery image id (used for basic FAQs)
	
	private $links_wrap_up 	= array(); 	// array containing page urls involved in FAQ choices array('pag_id' => url)
	private $involved_links = array();
	
	
	
	function __construct($faq_id) {
		$this->faq_id = $faq_id;
	}
	
	
	
	public function get_code($search_context = true) {
		$faq_status = get_post_status($this->faq_id);
		$close_btn 	= ($search_context) ? '<span class="fr_back_to_faqs">×</span>' : '';
		
		if(!$faq_status || $faq_status != 'publish') {
			return $close_btn.'No FAQ corresponding to this ID';	
		}
		$this->faq_type = get_post_meta($this->faq_id, 'fr_faq_type', true);
		
		
		// load choices structure
		$this->choices = fr_maybe_uncompress(get_post_meta($this->faq_id, 'fr_faq_choices', true));
		$this->choices = (empty($this->choices)) ? array() : json_decode($this->choices, true);
		
		
		// build
		$code = '
		<div class="fr_faq_contents fr_'. $this->faq_type .'_faq_type" data-faq-id="'. $this->faq_id .'">';
		
			if($search_context) {
				$code .= '<span class="fr_back_to_faqs">×</span>';
				$code .= '<h3 class="fr_faq_main_title">'. get_post_field('post_title', $this->faq_id) .'</h3>';
			}
			
			$GLOBALS['fr_is_getting_excerpt'] = true;
        
            // is managed through Elementor?
            if(defined('ELEMENTOR_URL') && get_post_meta($this->faq_id, '_elementor_edit_mode', true) == 'builder') {
                $elem_front = new Elementor\Frontend();
                $excerpt = $elem_front->get_builder_content($this->faq_id, true); 

                // JS to add class to body
                $excerpt .= '<script type="text/javascript">document.body.className += " elementor-page-'. $this->faq_id .'";</script>';

                // be sure JS is added
                $elem_front->enqueue_scripts();
            }
            
            else {
                $excerpt = wpautop(trim(get_post_field('post_content', $this->faq_id)));
                //$excerpt = apply_filters('the_content', $excerpt); // might interfere with other systems
                $excerpt = do_shortcode(do_blocks($excerpt));
            }
        
			$GLOBALS['fr_is_getting_excerpt'] = false;
			
			if($excerpt) {
				$code .= '<div class="fr_main_faq_txt">'. $excerpt .'</div>';
			}
			
			
			
			// basic? check for gallery and Knowledgebase - then stop
			if($this->faq_type == 'basic') {	
				$code .= $this->basic_faq_gallery() . $this->basic_faq_kb() . $this->rating_box();	
				
				// SEO schema.org JSON
				$code .= (!$search_context) ? $this->schema_json($excerpt) : ''; 
				
				return $code .'</div>'; // .fr_faq_contents closing;
			}
			
			
			///////
			
			
			// choice-based - print first question and choices
			$code .= '	
			<h4 class="fr_init_question fr_new_question">'. (string)get_post_meta($this->faq_id, 'fr_init_question', true) .'</h4>
			
			<div class="fr_faq_choice_wrap" data-for-choice="'. $this->faq_id .'_main">
				<div class="fr_faq_choice_dd fr_custom_dd">
					<section><em>'. __('select an option', 'fr_ml') .'</em></section>
							
					<ul class="fr_faq_choices_dd fr_custom_dd_list">';
						
						foreach($this->choices as $ch_id => $ch_data) {
							$code .= '<li data-val="'. $ch_id .'">'. $ch_data['opt_name'] .'</li>';
						}
	
				$code .= '
					</ul>
				</div>
			</div>';
			
			
			// rating box 
			$code .= $this->rating_box();
			
		
			// print predefined ends in hidden wrappers
			foreach(array('fr_solution_case', 'fr_user_act_case') as $case) {
				$code .= '
					<div id="'. $case .'_wrap" style="display: none;">
						<div class="'. $case .'">'. do_shortcode(get_option($case)) .'</div>
					</div>';
			}
	
		$code .= 
		'</div>'; // .fr_faq_contents closing
	

		// prepare data to be used in JS vars
		$this->set_choices_for_js($this->choices);
		$this->set_imgs_for_js($this->choices);
		$this->set_links_for_js($this->choices);
		
	
		// JS data to know structure
		$code .= '
		<script type="text/javascript">
		fr_faq_choices	= jQuery.parseJSON("'. addslashes(json_encode($this->choices_wrap_up)) .'"); 
		fr_faq_imgs		= jQuery.parseJSON("'. addslashes(json_encode($this->imgs_wrap_up)) .'");
		fr_faq_links	= jQuery.parseJSON("'. addslashes(json_encode($this->links_wrap_up)) .'"); 
		</script>';
		
		return $code;
	}
	
	
	
	/* 
	 * given an array of choices, re-arranges choices to be recalled just by their id 
	 * made to act recursively for sub-choices
	 */
	private function set_choices_for_js($choices) {
		
		foreach($choices as $id => $data) {
			
			$data['txt'] = do_shortcode($data['txt']);
			$clone = $data;
			
			if(!empty($clone['choices'])) {
				$clone['choices'] = array_keys($clone['choices']);
			}
			
			$this->choices_wrap_up[$id] = $clone; 
				
			if($data["on_choice"] == 'question' && !empty($data['choices'])) {
				$this->set_choices_for_js($data['choices']); 	
			}
		}
		return true;
	}
	
	
	
	/* 
	 * given an array of choices, collects images and prepare the array containing thumb and full-res URLs in $imgs_json 
	 * made to act recursively for sub-choices
	 */
	private function set_imgs_for_js($choices, $recursive = false) {
		foreach($choices as $id => $data) {
			if(!empty($data['gallery']) && is_array($data['gallery'])) {
				$this->involved_imgs = array_merge($this->involved_imgs, $data['gallery']);  	
			}		
			if($data["on_choice"] == 'question' && !empty($data['choices'])) {
				$this->set_imgs_for_js($data['choices'], true); 	
			}
		}
		
		// cycle ended - if top level - compose and store
		if(!$recursive) {
			foreach(array_unique($this->involved_imgs) as $img_id) {				
				$img_id = fr_wpml_translated_pag_id($img_id, 'attachment');
				
				$thumb_data 	= wp_get_attachment_image_src($img_id, 'medium');
				$fullres_data 	= wp_get_attachment_image_src($img_id, 'full');
				
				if(is_array($thumb_data)) {
					$this->imgs_wrap_up[$img_id] = array(
						'thumb' => $thumb_data[0],
						'full'	=> $fullres_data[0]
					);
				}
				
				// TODO - add data for captions
			}		
		}
		return true;
	}
	
	
	
	/* 
	 * given an array of choices, collects links and prepare the array containing pages url in $links_json 
	 * made to act recursively for sub-choices
	 */
	private function set_links_for_js($choices, $recursive = false) {
		foreach($choices as $id => $data) {
			if(!empty($data['kb']) && is_array($data['kb'])) {
				$this->involved_links = array_merge($this->involved_links, $data['kb']);  
			}
			if($data["on_choice"] == 'question' && !empty($data['choices'])) {
				$this->set_links_for_js($data['choices'], true); 	
			}
		}
		
		// cycle ended - if top level - compose and store
		if(!$recursive) {
			foreach(array_unique($this->involved_links) as $pag_id) {				
				$pag_id = fr_wpml_translated_pag_id($pag_id, 'fr_kb');
				
				$is_ext_link 	= false;
				$link_ref 		= $pag_id; 
			
				if(substr($pag_id, 0, 4) == 'ext-') {
					$is_ext_link = true;
					$pag_id = str_replace('ext-', '', $pag_id);
				}
				$permalink = ($is_ext_link) ? get_the_excerpt($pag_id) : get_permalink($pag_id);
				
				if($permalink) {
					$this->links_wrap_up[$link_ref] = array(
						'title'	=> get_the_title($pag_id),
						'url'	=> $permalink
					);
					
					// TODO - add nofollow system
				}
			}	
		}
		return true;
	}
	
	
	
	
	///////////////////////////////////////////////////////
	
	
	
	
	/* Returns basic FAQ's gallery */
	private function basic_faq_gallery() {
		$gallery = get_post_meta($this->faq_id, 'fr_basic_faq_gallery', true);
			
		if(empty($gallery) || !is_array($gallery)) {
			return '';	
		}
	
		// wrap up links code to be sure there's at least one valid 
		$imgs = array();
		$a = 0;
		foreach($gallery as $img_id) {
			$img_id = fr_wpml_translated_pag_id($img_id, 'attachment');
			
			$thumb_data 	= wp_get_attachment_image_src($img_id, 'medium');
			$fullres_data 	= wp_get_attachment_image_src($img_id, 'full');
				
			if(is_array($thumb_data)) {
				if(!$a) {
					$this->first_img_id = $img_id;	
				}

				$imgs[] = '<a href="'. $fullres_data[0] .'"><img src="'. $thumb_data[0] .'" alt="'. esc_attr(get_the_title($img_id)) .'" /></a>';	
				$a++;
			}
		}
		if(empty($imgs)) {
			return '';	
		}
		
		
		// otherwise return the full code
		return 
		'<div id="fr_basic_faq_gallery_'. $this->faq_id .'" class="fr_basic_faq_gallery fr_choice_gall_wrap">
			<div class="fr_choice_gall_inner">
				'. implode('', $imgs) .'
			</div>
		</div>
		
		<script type="text/javascript">
		jQuery(document).ready(function($) {
			$("#fr_basic_faq_gallery_'. $this->faq_id .' .fr_choice_gall_inner").justifiedGallery({
				rowHeight 		: fr_gall_img_h,
				maxRowHeight 	: "200%",
				lastRow 		: "nojustify",
				margins 		: 7,
				border			: 0
			});
			
			$("#fr_basic_faq_gallery_'. $this->faq_id .' .jg-entry").simpleLightbox({
				sourceAttr 		: "href",
				fileExt			: false,
				className		: "fr_lb",
				history			: false,
				showCounter		: false,
				disableScroll	: false
			});
		});
		</script>';
	}
	
	
	
	/* Returns basic FAQ's knowledge base links list */
	private function basic_faq_kb() {
		$kb = get_post_meta($this->faq_id, 'fr_basic_faq_kb', true);
			
		if(empty($kb) || !is_array($kb)) {
			return '';	
		}
	
		// wrap up links code to be sure there's at least one valid 
		$links = array();
		foreach($kb as $pag_id) {
			$pag_id = fr_wpml_translated_pag_id($pag_id, 'fr_kb');
			$is_ext_link = false;
			
			if(substr($pag_id, 0, 4) == 'ext-') {
				$is_ext_link = true;
				$pag_id = str_replace('ext-', '', $pag_id);
			}
			$permalink = ($is_ext_link) ? get_the_excerpt($pag_id) : get_permalink($pag_id);
				
			if($permalink) {
				$links[] = '<li><a href="'. $permalink .'" target="_blank">'. get_the_title($pag_id) .'</a></li>';	
			}
		}
		if(empty($links)) {
			return '';	
		}
		
		// otherwise return the full code
		return 
		'<h6 class="fr_choice_kb_legend">'. get_option('fr_kb_legend', 'Related articles:') .'</h6>
		<ul class="fr_choice_kb">
			'. implode('', $links) .'
		</ul>';
	}
	
	
	
	
	///////////////////////////////////////////////////////
	
	
	
	/* rating box code */
	private function rating_box() {
		if(!get_option('fr_use_rating')) {
			return '';	
		}
		$cookie_name = 'fr_faq_'. $this->faq_id .'_vote';
		
		
		// check if user already voted
		if(isset($_COOKIE[$cookie_name])) {
			$txt = __('You already voted', 'fr_ml');
			$sel = $_COOKIE[$cookie_name];
		}
		else {
			$txt = get_option('fr_rating_legend', 'Was this helpful?');
			$sel = '';	
		}
		
		$alr_voted_class 	= (isset($_COOKIE[$cookie_name])) ? 'fr_already_voted' : '';	
		$up_sel_class 		= ($sel == 'up') ? 'fr_rating_choice' : '';
		$down_sel_class 	= ($sel == 'down') ? 'fr_rating_choice' : '';
		$compact_class		= (get_option('fr_compact_rating')) ? 'fr_compact_rating' : '';
		
		return '
		<div class="fr_rating_box '. $alr_voted_class .' '. $compact_class .'" data-fid="'. $this->faq_id .'">
			<p>'. $txt .'</p>

			<span class="fr_faq_upvote '. $up_sel_class .'"><i class="dashicons dashicons-thumbs-up"></i></span>
			<span class="fr_faq_downvote '. $down_sel_class .'"><i class="dashicons dashicons-thumbs-down"></i></span>';
			
		return $code .'
		</div>';	
	}
	
	
	///////////////////////////////////////////////////////
	
	
	
	
	/* prints the LD+JSON code for Google's schema integration about Question & answer */
	private function schema_json($excerpt) {
		
		$faq_title 	= addslashes(get_post_field('post_title', $this->faq_id)); 
		$faq_url 	= get_permalink($this->faq_id);
		
		$img_url 	= (!empty($this->first_img_id)) ? wp_get_attachment_image_src($this->first_img_id) : '';
		$img_url 	= ($img_url) ? $img_url[0] : '';
		$img_part 	= '';
		
		if($img_url) {
			$img_part = ',
			"primaryImageOfPage": {
				"@type": "ImageObject",
				"name": "'. $img_url .'"
			}';	
		}
		
		
		$upvotes 	= (int)get_post_meta($this->faq_id, 'fr_upvotes', true); 
		$downvotes 	= (int)get_post_meta($this->faq_id, 'fr_downvotes', true); 
		
		
		/////////
		return '
		<script type="application/ld+json">
        {
            "@context"		: "http://schema.org/",
            "@type"			: "QAPage",
            "mainEntity": [{
                "@type"			: "Question",
				"@id"			: "'. $faq_url .'",
				"name"			: "'. $faq_title .'",
				"image"			: "'. $img_url .'",
				"upvoteCount"	: "'. $upvotes .'",
				"downvoteCount"	: "'. $downvotes .'",
				"answerCount"	: "1",

				"suggestedAnswer" : {
					"@type"			: "Answer",
					"@id"			: "'. $faq_url .'",
					"url"			: "'. $faq_url .'",
					"upvoteCount"	: "'. $upvotes .'",
					"downvoteCount"	: "'. $downvotes .'",
					"text"			: `'. wp_kses_post($excerpt) .'`
				},
				"acceptedAnswer": {
					"@type"			: "Answer",
					"@id"			: "'. $faq_url .'",
					"url"			: "'. $faq_url .'",
					"upvoteCount"	: "'. $upvotes .'",
					"downvoteCount"	: "'. $downvotes .'",
					"text"			: `'. wp_kses_post($excerpt) .'`
				}
            }]
            '. $img_part .'
        }
		</script>';
	}
	
}



///////////////////////////////////////////////////////////////////////////



// shortcut function
function fr_front_faq_code($faq_id, $search_context = true) {
	if(empty($faq_id)) {
		return '';	
	}
	
	$class = new fr_front_faq_code_class($faq_id);
	return $class->get_code($search_context);	
}




// override FAQ page contents
function fr_faq_pag_contents($contents) {
	global $post;
	if(!isset($post->post_type) || $post->post_type != 'fr_faqs') {return $contents;}
	if(isset($GLOBALS['fr_is_getting_excerpt']) && $GLOBALS['fr_is_getting_excerpt']) {return $contents;}

	return fr_front_faq_code($post->ID, false);
}
add_filter('the_content', 'fr_faq_pag_contents', 900);