<?php
// DIRECT WOOCOMMERCE FAQ INJECTION IN TAB

class fr_woocomm_faq_tab {

    private $meta_key = 'fr_woocom_faq_tab';
    private $prefix = 'fr_wc_ft_';
    
    
    // restriction's option structure
	private $meta_structure = array(
		'enabled' => 'default',
		'subj' 	  => 'default',
        'exclude' => '',
	);
    
    
    /* initialization - setup hooks */
	function __construct() {

        // add the fields to the affected taxonomies
        add_action('product_cat_add_form_fields', array($this, 'terms_form_implementation'));
        add_action('product_cat_edit_form_fields', array($this, 'terms_form_implementation'));

        // tax save fields
        add_action('created_product_cat', array($this, 'term_fields_save'));
        add_action('edited_product_cat', array($this, 'term_fields_save'));	
		
		// clean database on term's deletion
		add_action('deleted_term_taxonomy', array($this, 'clean_db_on_terms_remove'));
		
        
        // post types implementation
		add_action('admin_init', array($this, 'pt_metabox_setup')); 
		add_action('save_post', array($this, 'post_fields_save'));
        
        
		// frontend
        add_filter('woocommerce_product_tabs', array($this, 'frontend_tab_register'));
	}
    
    
    
    /* Save values into a meta
	 * @param (string) $subj_type = term or post
	 * @param (int) $subj_id = term/post ID
	 */
	public function save_restrictions($subj_type, $subj_id) {
		if(!isset($_POST['fr_wc_ft_nonce']) || !wp_verify_nonce($_POST['fr_wc_ft_nonce'], 'fr_wc_ft_nonce')) {
			return false;
		}
		$fetched_data = array();
		
		foreach($this->meta_structure as $key => $def_val) {
            $fetched_data[$key] = $def_val;	
			
            if(isset($_POST[ $this->prefix . $key ])) {
				$val = $_POST[ $this->prefix . $key ];
				
				// check array values	
				$fetched_data[$key] = (is_array($val)) ? implode(',', $val) : $val;		
			}
		}
		
		// save
		if($subj_type == 'term') {
			fr_set_term_meta($subj_id, $this->meta_key, $fetched_data);
		} else {
			update_post_meta($subj_id, $this->meta_key, $fetched_data);
		}
		
		return $fetched_data;
	}
    
    
    
    //////////////////////////////////////////////////////////////////////////////////////


    
	/* terms wizard implementation */
	public function terms_form_implementation($term_data) {
        $title = 'FAQ Revolution - '. esc_html__("FAQ tab", 'fr_ml'); 
        
		//check for existing taxonomy meta for term ID
		$term_id = (is_object($term_data)) ? $term_data->term_id : false;
		
		// if "edit term" view
		if(!is_object($term_data)) : 
			?>
			<div class="form-field fr_tax_wc_ft_wizard">
				<h4><?php echo $title ?></h4>
				<?php echo $this->wizard_code('tax', $term_id) ?>
			</div>
	
    
		<?php else: 
			$this->term_data = $term_data;
		?>
        
		 <tr class="form-field">
			<th scope="row" valign="top"></th>
	
			<td class="fr_wc_ft_wizard_td">
				<div class="form-field fr_tax_wc_ft_wizard">
					<h4><?php echo $title ?></h4>
					<?php echo $this->wizard_code('tax', $term_id) ?>
				</div>
			</td>
		</tr>
		<?php
		endif;
	}
	
    
	/*  term fields save */
	public function term_fields_save($term_id) {
		$data = $this->save_restrictions('term', $term_id);
	}
	
    
	/* on term's deletion - delete related option */
	public function clean_db_on_terms_remove($term_id) {
		fr_del_term_meta($term_id, $this->meta_key);
	}
    
    
    
    //////////////////////////////////////////////////////////////////////////////////////


    
	/* Post types metabox setup */
	public function pt_metabox_setup() {
        add_meta_box('fr_wc_ft_meta', "FAQ Revo - ". __("FAQ tab", 'fr_ml'), array($this, 'posts_form_implementation'), 'product', 'side', 'default');
	}

	/* posts wizard implementation */
	public function posts_form_implementation() {
		global $post;
		echo $this->wizard_code('post', $post->ID);
	}
	
	/* post fields save */
	public function post_fields_save($post_id) {
		$data = $this->save_restrictions('post', $post_id);
	}
    
    
    
    //////////////////////////////////////////////////////////////////////////////////////


    
	/* Returns restrictions wizard HTML to be inserted in metabox
	 * @param (string) $subj_type = tax or post
	 * @param (int|bool) $subj_id = term/post ID or false
	 */
	public function wizard_code($subj_type, $subj_id = false) {

		$data = ($subj_type == 'tax') ? (array)fr_get_term_meta($subj_id, $this->meta_key) : (array)get_post_meta($subj_id, $this->meta_key, true); 
		$data = array_merge($this->meta_structure, $data);
        
		$tax_tb = ($subj_type == 'tax') ? '<br/>' : '';
		$default_opt_txt = ($subj_type == 'tax') ? esc_html__('as defined in settings', 'fr_ml') : esc_html__('as defined in categories or settings', 'fr_ml');
        
		
		// Wizard's code
		$code = '
		<div class="fr_wc_ft_wizard_wrap">
			<div class="fr_wc_ft_wizard_block fr_wc_ft_cont_h">
				<fieldset>
					<label>'. esc_html__('Enable tab?', 'fr_ml') .'</label>
					<select name="'. $this->prefix .'enabled" autocomplete="off">
						<option value="default">('. $default_opt_txt .')</option>
                        <option value="1" '. selected('1', $data['enabled'], false) .' >'. esc_html__('Yes') .'</option>
                        <option value="0" '. selected('0', $data['enabled'], false) .'>'. esc_html__('No') .'</option>
					</select>
				</fieldset>
				<fieldset>
					<hr/>
					<label>'. esc_html__('Default subject', 'fr_ml') .'</label>
					<select name="'. $this->prefix .'subj" autocomplete="off">
						<option value="default">('. $default_opt_txt .')</option>
                        <option value="" '. selected('', $data['subj'], false) .'>('. esc_html__('none') .')</option>';
        
                        foreach(fr_sub_subsubjs_for_builders() as $key => $val) {
                            $code .= '<option value="'. esc_attr($key) .'" '. selected($key, $data['subj'], false) .'>'. esc_html($val) .'</option>';            
                        }
        
                        $code .= '
					</select>
				</fieldset>
                <fieldset>
					<hr/>
					<label>'. esc_html__('Excluded subjects', 'fr_ml') .'</label>
					<select name="'. $this->prefix .'exclude" autocomplete="off" multiple>';
                    
                        foreach(fr_sub_subsubjs_for_builders(true) as $key => $val) {
                            $sel = (in_array($key, (array)$data['exclude'])) ? 'selected="selected"' : '';
                            $code .= '<option value="'. esc_attr($key) .'" '. $sel .'>'. esc_html($val) .'</option>';            
                        }
        
                        $code .= '
					</select>
				</fieldset>
			</div>

			<input type="hidden" name="fr_wc_ft_nonce" value="'. wp_create_nonce('fr_wc_ft_nonce') .'" />
		</div>';
		
		
		// javascript
		$code .= '
		<script type="text/javascript">
		jQuery(document).ready(function($) {
            new lc_select(".fr_wc_ft_wizard_wrap select", {
                wrap_width : "100%",
                addit_classes : ["lcslt-lcwp"],
            });
        });
		</script>';
		
		return $code;
	}
    
    
    
    //////////////////////////////////////////////////////////////////////////////////////


    
    // retrieve the final value considering product meta, tax meta and global options
    private function get_final_val($key) {
        global $post;
        
        $post_id    = $post->ID;
        $val        = ($key == 'exclude') ? '' : 'default';
        
        // post val 
        $post_meta = (array)get_post_meta($post_id, $this->meta_key, true);
        if(is_array($post_meta) && isset($post_meta[$key])) {
            $val = $post_meta[$key];    
        }
        
        // check among terms
        $terms = wp_get_object_terms($post_id, 'product_cat', array('fields' => 'ids'));
        foreach($terms as $term_id) {
            if($val == 'default' || ($key == 'exclude' && !$val)) {
                
                $term_meta = (array)fr_get_term_meta($term_id, $this->meta_key);
                if(is_array($term_meta) && isset($term_meta[$key])) {
                    $val = $term_meta[$key];    
                }        
            }
        }
        
        // global value
        if($val == 'default' && $key != 'exclude') {
            $val = ($key == 'enabled') ? get_option('fr_wc_tab_def_status') : get_option('fr_wc_tab_def_subj');
        }
        
        return $val;
    }
    
    
    
    public function frontend_tab_register($tabs) {

        if(!$this->get_final_val('enabled')) {
            return $tabs;
        }

        // Adds the new tab
        $tabs['fr_faq'] = array(
            'title'     => get_option('fr_wc_tab_title', 'FAQ'),
            'priority'  => get_option('fr_wc_tab_priority', 80),
            'callback'  => array($this, 'frontend_cb')
        );
        return $tabs;
    }
    
    
    
    // frontend callback
    public function frontend_cb() {
        $def_txt = get_option('fr_wc_tab_pre_txt');
        $spacer = (trim($def_txt)) ? '<p>&nbsp;</p>' : '';

        echo do_shortcode(
            $def_txt .
            $spacer .
            '[faq-revo-searchbar subj_n_child="'. esc_attr($this->get_final_val('subj')) .'" excl_subj="'. esc_attr($this->get_final_val('exclude')) .'"]'
        );
    }
    
}
new fr_woocomm_faq_tab();

