<?php 
// FAQ BUILDER - basically the metabox creating FAQ structure + FAQ type + custom order and search helper box



//////////////////////////
// REGISTER
function fr_faqs_register_metaboxes() {
    add_meta_box('fr_faq_main_fields', __('FAQ Panel', 'fr_ml'), 'fr_faq_main_fields', 'fr_faqs', 'side', 'core');
	add_meta_box('fr_search_helper_box', __('Search Helper', 'fr_ml'), 'fr_search_helper_box', 'fr_faqs', 'side', 'low');
	
	add_meta_box('fr_basic_faq_data', __('Basic FAQ - additional data', 'fr_ml'), 'fr_basic_faq_data', 'fr_faqs', 'normal', 'default');
	add_meta_box('fr_faq_builder', __('Choices Tree', 'fr_ml'), 'fr_faq_builder', 'fr_faqs', 'normal', 'default');
}
add_action('admin_init', 'fr_faqs_register_metaboxes');





//////////////////////////
// FAQ TYPE AND SORTING + RATINGS - INJECT IT IN TOP PANEL

function fr_faq_main_fields() {
	global $current_screen, $post;

	if(!is_object($current_screen) || !isset($current_screen->id) || $current_screen->id != 'fr_faqs') {
		return false;	
	}
    dike_lc('lcweb', 'fr', true);
    
	
	$type	=  get_post_meta($post->ID, 'fr_faq_type', true); 
	$order	=  (int)get_post_meta($post->ID, 'fr_sort_order', true);
	
	
	$upvotes 	= (int)get_post_meta($post->ID, 'fr_upvotes', true); 
	$downvotes 	= (int)get_post_meta($post->ID, 'fr_downvotes', true); 
	
	$up_nocolor_class 	= (!$upvotes) ? 'fr_nocolor_rating' : ''; 
	$down_nocolor_class = (!$downvotes) ? 'fr_nocolor_rating' : ''; 
	?>

    <div class="lcwp_sidebox_meta">
        <div class="misc-pub-section misc-pub-post-fr-type"><?php esc_attr_e('Type', 'fr_ml') ?>:
            <select name="fr_faq_type" autocomplete="off">
                <option value="choices"><?php esc_attr_e('Choice-based', 'fr_ml') ?></option>
                <option value="basic" <?php echo str_replace("'", '"', selected($type, 'basic', false)) ?>><?php esc_attr_e('Basic (text only)', 'fr_ml') ?></option>
            </select>
        </div>
        <div class="misc-pub-section misc-pub-post-fr-order"><?php esc_attr_e('Order', 'fr_ml') ?>:
            <input type="number" value="<?php echo (int)$order ?>" name="fr_sort_order" min="0" step="1" style="width: 75px;" autocomplete="off" />
        </div>
        <div class="misc-pub-section misc-pub-post-fr-rating"><?php esc_attr_e('Rating', 'fr_ml') ?>: &nbsp; 
            <span class="fr_upvote_color <?php echo $up_nocolor_class ?>"><i class="dashicons dashicons-thumbs-up"></i><?php echo $upvotes ?></span>
            <span class="fr_downvote_color <?php echo  $down_nocolor_class ?>"><i class="dashicons dashicons-thumbs-down"></i><?php echo $downvotes ?></span>
        </div>
    </div>    
	<?php
}
//add_action('admin_footer', 'fr_faq_main_fields');






//////////////////////////
// SEARCH HELPER + SUBJS HIERARCHY FIX

function fr_search_helper_box() {
	global $post;
	$helper = get_post_meta($post->ID, 'fr_search_helper', true);
	?>
    <div class="lcwp_sidebox_meta">
        <div class="misc-pub-section">
          <textarea name="fr_search_helper" rows="2" style="width: 100%;"><?php echo $helper ?></textarea>
        </div>
    </div>
    
    <input type="hidden" name="fr_faq_noncename" value="<?php echo wp_create_nonce('lcwp_nonce') ?>" />
	<?php
	
	
	// hierarchy fix - create a JSON string with FAQ subjs array
	$hierarchic_subjs = get_terms('fr_faq_subjs', array(
		'taxonomy' 		=> 'fr_faq_subjs',
		'hide_empty' 	=> false,
		'fields'		=> 'id=>parent'
	));
	
	if(is_array($hierarchic_subjs) && !empty($hierarchic_subjs)) :
		?>
		<script type="text/javascript">
        (function($) { 
            "use strict";    
            
            $(document).ready(function() {
                var hs = $.parseJSON('<?php echo json_encode($hierarchic_subjs) ?>');
                var acted = false;

                $.each(hs, function(subj_id, parent_id) {

                    // if has parent - move
                    if(parseInt(parent_id, 10) && !$('#fr_faq_subjs-'+subj_id).parent().hasClass('children')) {
                        var $subj_li = $('#fr_faq_subjs-'+subj_id).detach();

                        if(!$('#fr_faq_subjs-'+parent_id+' ul').length) {
                            $('#fr_faq_subjs-'+parent_id).append('<ul class="children"></ul>');	
                        }

                        $('#fr_faq_subjs-'+parent_id+' ul').append($subj_li);
                        acted = true;
                    }
                });

                // sort alphabetically
                if(acted) {
                    $('#fr_faq_subjschecklist ul.children').each(function() {
                        var $ul 	= $(this),
                            elems 	= {};

                        // detach using name as key
                        $ul.find('> li').each(function() {
                            if($(this).find('input').is(':checked')) { // checked ones are already sorted
                                return true;	
                            }

                            var key = $(this).find('label').text() +'-'+ $(this).find('input').val();
                            elems[ key ] = $(this).detach();	
                        });

                        // sort
                        var sorted = {};
                        Object.keys(elems).sort().forEach(function(key) {
                            sorted[key] = elems[key];
                        });

                        // append
                        $.each(sorted, function(i, $li) {
                            $ul.append($li);
                        });
                    });	
                }
            });
        })(jQuery);
		</script>
		<?php
	endif;
	return true;	
}





//////////////////////////
// BASIC FAQ - ADDITIONAL DATA

function fr_basic_faq_data() {
	
	include_once(FR_DIR .'/classes/admin_choices_code.php');
	global $post;
	
	$choices_code 	= new fr_admin_choices_code;
	$gallery 		= get_post_meta($post->ID, 'fr_basic_faq_gallery', true);
	$kb 			= get_post_meta($post->ID, 'fr_basic_faq_kb', true);
	
	$code = '
	<div>
		<label>
			'. __('FAQ gallery', 'fr_ml') .'
			<span class="fr_gallery_add" title="'. esc_attr__('add image', 'fr_ml') .'">+</span>
		</label>
		<ul class="fr_choice_gallery" style="padding-left: 7px;">';
		
		if(!is_array($gallery)) {$gallery = array();}
		foreach($gallery as $img_id) {
			$img_data = wp_get_attachment_image_src($img_id);
			$code .= '
			<li style="background-image: url(\''. $img_data[0] .'\');">
				<span class="fr_gallery_del dashicons dashicons-dismiss" title="'. esc_attr__("remove image", 'fr_ml') .'"></span>
				<input type="hidden" name="fr_basic_faq_gallery[]" value="'. $img_id .'" />
			</li>';
		}
		
		$code .= '
		</ul>
	</div>
	
	<hr/>
	<div>
		<label>'. __('Linked articles', 'fr_ml') .'</label>
		<select name="fr_basic_faq_kb[]" class="fr_lc_select" multiple="true" autocomplete="off">
		
			<optgroup label="'. __('Knowledge Base Articles', 'fr_ml') .'">';
			
				foreach($choices_code->get_kb_articles() as $kb_id => $kb_name) {
					$selected = (is_array($kb) && count($kb) && in_array($kb_id, $kb)) ? 'selected="selected"' : '';
					$code .= '<option value="'. $kb_id .'" '. $selected .'>'. $kb_name .'</option>';
				}	
			
			
			$code .= '
			</optgroup>
			<optgroup label="'. __('External Links', 'fr_ml') .'">';
			
				foreach($choices_code->get_ext_links() as $el_id => $el_name) {
					$selected = (is_array($kb) && count($kb) && in_array($el_id, $kb)) ? 'selected="selected"' : '';
					$code .= '<option value="'. $el_id .'" '. $selected .'>'. $el_name .'</option>';
				}		

	$code .= '
			</optgroup>
		</select>
	</div>';
	
	echo $code;	
}





//////////////////////////
// CHOICES BUILDER

function fr_faq_builder() {
	include_once(FR_DIR .'/classes/admin_choices_code.php');

	global $post;
	$choices_code = new fr_admin_choices_code;

	$init_question	= (string)get_post_meta($post->ID, 'fr_init_question', true);
	$structure		= fr_maybe_uncompress(get_post_meta($post->ID, 'fr_faq_choices', true));
	?>
    
    <div id="fr_global_toggle_choices"> 
        <input type="button" value="<?php esc_attr_e('Expand choices', 'fr_ml') ?>" class="fr_glob_expand button-secondary" />
        <input type="button" value="<?php esc_attr_e('Compress choices', 'fr_ml') ?>" class="fr_glob_compress button-secondary" />
    </div>
    
    <div id="fr_init_question_wrap">
    	<input type="text" name="fr_init_question" value="<?php echo esc_attr($init_question) ?>" placeholder="<?php esc_attr_e('initial question', 'fr_ml') ?>" autocomplete="off" />
    </div>
    
    <div id="fr_choices_container" class="lcwp_mainbox_meta" style="direction: LTR;">	 
		<?php 
		echo (empty($structure)) ? $choices_code->get_code() . $choices_code->get_code() : $choices_code->get_code( json_decode($structure, true) );
		?> 
	</div> 
    
    <div id="fr_new_choice_wrap" style="display: none;">
    	<?php echo $choices_code->get_code(array(), true); ?>
    </div>
    
    <div style="display: none;">
    	<textarea name="fr_faq_choices"><?php echo $structure ?></textarea>
    </div>


    <script type="text/javascript">
    (function($) { 
        "use strict";
        
        $(document).ready(function() {
            var choice_code 	= $('#fr_new_choice_wrap').html(),

                faq_id 			= <?php echo (int)$post->ID ?>, 
                saving_error 	= false,
                choice_id 		= 0, // increasing number associating an unique value to choices
                structure_saved = false;



            // save choices structure
            $(document).on('click', '#publish', function(e) {

                // already saved - allow saving
                if(structure_saved) {
                    return true;	
                }

                e.preventDefault();
                saving_error 	= false;
                choice_id 		= 0;

                // cycle 
                var $row = $('#fr_choices_container'),	
                    choices_data = child_choices_data($row); // acts also recursively	

                // FAQ must have a title
                if(!$.trim($('#title').val())) {
                    lc_wp_popup_message('error', "<?php esc_attr_e('FAQ must have a title', 'fr_ml') ?>");
                    return false;		
                }


                // if is a basic FAQ and there is no description - trigger error
                if($('[name=fr_faq_type]').val() == 'basic') {
                    var basic_txt = ($('#content').is(':visible')) ? $.trim($('#content').val()) : tinymce.editors.content.getContent();

                    if(!basic_txt) {
                        lc_wp_popup_message('error', "<?php esc_attr_e('Please insert a FAQ description', 'fr_ml') ?>");
                        return false;	
                    }
                }

                // if there's an error in choices and the type is based on them
                else {
                    if( !$.trim( $('[name=fr_init_question]').val())) {
                        lc_wp_popup_message('error', "<?php esc_attr_e('There must be an initial question', 'fr_ml') ?>");
                        return false;	
                    }

                    if(saving_error) {
                        lc_wp_popup_message('error', "<?php esc_attr_e("One or more choices are missing option name or new question", 'fr_ml') ?>");
                        return false;	
                    }
                }


                // no errors - save
                structure_saved = true;

                // reset page unload check
                fr_safe_pageunload = true;

                // structure in textarea
                $('[name=fr_faq_choices]').val( JSON.stringify(choices_data) );
                $('#publish').trigger('click');
                return true;
            });


            // given a parent object, retrieves child choices data
            var child_choices_data = function($parent_choice) {
                var choices = {};

                $parent_choice.find('> .fr_choices_row').each(function() {
                    choice_id++; 		
                    choices[ faq_id+'_c'+choice_id ] = choice_data( $(this) );
                });

                return choices;
            };



            // given choice's row, return case's data
            var choice_data = function($row) {	
                var $choice 	= $row.find('> .fr_choice'), 
                    data 		= {},
                    opt_name 	= $.trim( $choice.find('[name=opt_name]').val()),
                    on_choice 	= $choice.find('[name="fr_on_choice"]').val(),
                    new_quest	= $.trim( $choice.find('[name=new_quest]').val());	

                if(!opt_name || (on_choice == 'question' && !new_quest)) {
                    saving_error = true;
                    return {};
                }

                // has child choices?
                var child_choices = (on_choice != 'question') ? {} : child_choices_data($row);  			

                // get tinymce text
                var txt = '';	
                if(on_choice != 'def_solution' && on_choice != 'def_user_act') {
                    if( $.trim( tinyMCE.get( $choice.find('.fr_node_txt').data('tinymce-id') ).getContent() ) ) {
                        var txt = tinyMCE.get( $choice.find('.fr_node_txt').data('tinymce-id') ).getContent({format : 'raw'});	
                    }
                }

                return {
                    opt_name 	: opt_name,
                    on_choice	: on_choice, 
                    txt			: txt,
                    gallery		: choice_gallery_array($choice),
                    kb			: $choice.find('[name="fr_linked_kb[]"]').val(),
                    new_quest	: (on_choice == 'question') ? new_quest : '',
                    choices		: child_choices,	
                };
            };



            // given a choice object, returns the gallery images array 
            var choice_gallery_array = function($choice) {
                var gallery = [];

                $choice.find('.fr_choice_gallery li').each(function() {

                    gallery.push( $(this).data('img-id') );
                });

                return gallery;
            };




            //////////////////////////////////////////////////




            // hide choices if is a "basic"
            var toggle_builder_on_type_change = function() {

                if($('[name=fr_faq_type]').val() == 'basic') {
                    $('#fr_faq_builder').slideUp();
                    $('#fr_basic_faq_data').slideDown();	
                }

                else {
                    $('#fr_faq_builder').slideDown();	
                    $('#fr_basic_faq_data').slideUp();
                }
            };
            setTimeout(function() { // wait field to be in the page
                toggle_builder_on_type_change(); // on init
            }, 10);


            // on type change
            $(document).on('change', '[name=fr_faq_type]', function() {
                toggle_builder_on_type_change();
            });



            //////////////////////////////////////////////////



            // add choice
            $(document).on('click', '.fr_add_choice', function() {
                $(this).after(choice_code);

                fr_builder_lc_select();
                editor_setup();

                // remove "fr_child_choice" class on first level
                $('#fr_choices_container > .fr_child_choice').removeClass('fr_child_choice');
            });



            // delete choice
            $(document).on('click', '.fr_del_choice', function() {
                var $subj = $(this).parents('.fr_choices_row').first(), 
                    $wrap = $subj.parents('.fr_choices_row').first();


                // if there's only one choice - block
                if($wrap.find('> .fr_child_choice').length == 2 || $('#fr_choices_container .fr_del_choice').length == 2) {

                    alert("<?php esc_attr_e("There must be at least two choices", 'fr_ml') ?>");
                    return false;
                }
                else {
                    if(confirm("<?php esc_attr_e('Do you really want to delete this choice?', 'fr_ml') ?>")) {
                        $subj.next('.fr_add_choice').remove();
                        $subj.remove();
                    }
                }

            });



            // sort choices
            $(document).on('click', '.fr_sort_choice', function() {

                var $subj 			= $(this).parents('.fr_choices_row').first(), 
                    $wrap 			= ($subj.hasClass('fr_child_choice')) ? $subj.parents('.fr_choices_row').first() : $('#fr_choices_container'),
                    choices_count	= $wrap.find('> .fr_choices_row').length,
                    direction 		= ($(this).hasClass('fr_move_faq_down')) ? 'down' : 'up',
                    curr_pos 		= false; 

                // know current position
                $wrap.find('> .fr_choices_row').each(function(i, v) {

                    if($(this).is($subj)) {
                        curr_pos = i + 1;
                        return false;
                    }
                });

                // checkssss
                if(
                    (direction == 'up' && curr_pos == 1) ||
                    (direction == 'down' && curr_pos == choices_count)
                ) {
                    return false;	
                }


                // apply
                var target 	= (direction == 'up') ? curr_pos - 1 : curr_pos,
                    $block 	= $subj.detach();

                $wrap.find('> .fr_choices_row').each(function(i, v) {
                    var index = i + 1;

                    if(index == target) {
                        (direction == 'up') ? $(this).before($block) : $(this).after($block);		
                    }
                });
            });



            //////////////////////////////////////////////////



            // manage "on choice" change consequeces
            $(document).on('change', 'select[name=fr_on_choice]', function(e) {

                var val 		= $(this).val(),
                    $subj 		= $(this).parents('.fr_choices_row').first(),
                    $btn 		= $subj.find('.fr_toggle_choices'),
                    has_choices	= $subj.find('> .fr_child_choice:visible').length; 

                if(val == 'question') {
                    $btn.fadeIn();
                    $subj.find('.fr_node_txt').first().slideDown()

                    if(has_choices) {
                        $subj.find('> .fr_child_choice').show();
                        $subj.find('> .fr_child_choice').next('.fr_add_choice').show();	
                    }
                    else {
                        // append an empty choice
                        $subj.append(choice_code);	
                        $subj.append(choice_code);

                        editor_setup();
                        fr_builder_lc_select();
                    }

                    $subj.find('.fr_choice').first().find('.fr_node_question').slideDown();	
                }

                else {
                    if(has_choices) {
                        if(confirm("<?php esc_attr_e('This will delete child choices. Continue?', 'fr_ml') ?>")) {
                            $btn.fadeOut();	
                            $subj.find('> .fr_child_choice').hide();
                            $subj.find('> .fr_child_choice').next('.fr_add_choice').hide();
                            $subj.find('.fr_choice').first().find('.fr_node_question').slideUp();	

                            // hide text if node brings to default solution or user action
                            (val == 'def_solution' || val == 'def_user_act') ? $subj.find('.fr_node_txt').first().slideUp() : $subj.find('.fr_node_txt').first().slideDown(); 
                        }
                        else {
                            e.preventDefault();

                            $(this).find('option').removeAttr('selected');
                            $(this).find('option[value="question"]').prop('selected', 'selected');

                            return false;	
                        }
                    }
                    else {

                        // hide text if node brings to default solution or user action
                        (val == 'def_solution' || val == 'def_user_act') ? $subj.find('.fr_node_txt').first().slideUp() : $subj.find('.fr_node_txt').first().slideDown(); 	
                    }
                }	
            });



            // toggle choices visibility - global 
            $(document).on('click', '.fr_glob_compress', function() {
                $('.fr_toggle_choices').addClass('fr_tc_compressed');

                $('.fr_child_choice').hide();
                $('.fr_child_choice').next('.fr_add_choice').hide();
            });

            $(document).on('click', '.fr_glob_expand', function() {
                $('.fr_toggle_choices').removeClass('fr_tc_compressed');

                $('.fr_child_choice').show();
                $('.fr_child_choice').next('.fr_add_choice').show();
            });


            // compress single choice choices
            $(document).on('click', '.fr_toggle_choices:not(.fr_tc_compressed)', function() {
                var $subj = $(this).parents('.fr_choices_row').first();
                $(this).addClass('fr_tc_compressed');

                $subj.find('> .fr_child_choice').hide();
                $subj.find('> .fr_child_choice').next('.fr_add_choice').hide();
            });

            // expand single choice choices
            $(document).on('click', '.fr_tc_compressed', function() {
                var $subj = $(this).parents('.fr_choices_row').first();
                $(this).removeClass('fr_tc_compressed');

                $subj.find('> .fr_child_choice').show();
                $subj.find('> .fr_child_choice').next('.fr_add_choice').show();
            });



            ///////////////////////////////////////////



            // image gallery management
            var fr_lb_frame = false;


            // choices image gallery
            $(document).on('click', '.fr_choice .fr_gallery_add', function(e) {
                if($(e.target).hasClass('fr_gallery_del')) {return false;}	
                var $active_gallery = $(this).parents('.fr_choice').first().find('.fr_choice_gallery');

                // Create the media frame
                fr_lb_frame = wp.media.frames.file_frame = wp.media({
                  title		: "FAQ Revolution - <?php esc_attr_e("Case gallery - Image Picker", 'fr_ml') ?>",
                  button	: {
                    text	: "<?php _e('Select') ?>",
                  },
                  library 	: {type : 'image'},
                  multiple	: true
                });

                // When an image is selected, run a callback.
                fr_lb_frame.on('select', function() {
                    var code = '',
                        img_data = fr_lb_frame.state().get('selection').toJSON();

                    $.each(img_data, function(i, v) {
                        code += '<li data-img-id="'+ v.id +'" style="background-image: url(\''+ v.sizes.thumbnail.url +'\');"><span class="fr_gallery_del dashicons dashicons-dismiss" title="<?php esc_attr_e("remove image", 'fr_ml') ?>"></span></li>';
                    });

                    $active_gallery.append(code);
                });

                fr_lb_frame.open();
            });


            // Basic FAQ gallery
            $(document).on('click', '#fr_basic_faq_data .fr_gallery_add', function(e) {
                if($(e.target).hasClass('fr_gallery_del')) {return false;}	

                // Create the media frame
                fr_lb_frame = wp.media.frames.file_frame = wp.media({
                  title		: "FAQ Revolution - <?php esc_attr_e("Case gallery - Image Picker", 'fr_ml') ?>",
                  button	: {
                    text	: "<?php _e('Select') ?>",
                  },
                  library 	: {type : 'image'},
                  multiple	: true
                });

                // When an image is selected, run a callback.
                fr_lb_frame.on('select', function() {
                    var code = '',
                        img_data = fr_lb_frame.state().get('selection').toJSON();

                    $.each(img_data, function(i, v) {		
                        code += 
                        '<li style="background-image: url(\''+ v.sizes.thumbnail.url +'\');">'+
                            '<span class="fr_gallery_del dashicons dashicons-dismiss" title="<?php esc_attr_e("remove image", 'fr_ml') ?>"></span>'+
                            '<input type="hidden" name="fr_basic_faq_gallery[]" value="'+ v.id +'" />'+
                        '</li>';
                    });

                    $('#fr_basic_faq_data .fr_choice_gallery').append(code);
                });

                fr_lb_frame.open();
            });


            // galleries image removal
            $(document).on('click', '.fr_gallery_del', function() {

                if(confirm("<?php esc_attr_e("Remove this image?", 'fr_ml') ?>")) {
                    $(this).parents('li').remove();
                }

                return false;
            });


            // sortable images
            $(".fr_choice_gallery").sortable({
                items : "li",
            });
            $(".fr_choice_gallery").disableSelection();



            ///////////////////////////////////////////



            // ask for confirmation when exiting the page and FAQ structure changed
            var fr_safe_pageunload = true;

            $(document).on('input change', '#fr_faq_builder input, #fr_faq_builder select', function() {
                fr_safe_pageunload = false;
            });


            $(window).on('beforeunload', function(e){
                if(!fr_safe_pageunload) {
                    return "<?php esc_attr_e("Something hasn't been saved, leave the page?", 'fr_ml') ?>";
                }
            });



            ///////////////////////////////////////////



            // WYSIWYG editor setup
            var editor_setup = function() {	   
                var config = $.extend({}, tinyMCEPreInit.mceInit.content);

                //console.log(config); // debug

                config.cache_suffix		= false;
                config.external_plugins = false;
                config.toolbar1 		= "formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,pastetext,removeformat,undo,redo";
                config.toolbar2 		= "";
                config.statusbar		= false;
                config.body_class 		= "wp-autoresize";
                config.wp_autoresize_on = true;


                $('#fr_choices_container .fr_choice_txt').not('.fr_mce_applied').each(function() {
                    var id = 'fr_'+ Math.random().toString(36).substr(2, 9);

                    $(this).parents('.fr_node_txt').attr('data-tinymce-id', id);
                    $(this).addClass('fr_mce_applied').attr('id', id);

                    var spec_config = $.extend({}, config);
                        spec_config.selector = '#'+ id;

                    tinymce.init(spec_config);
                });
            };
            editor_setup(); // on init



            // LC select usage only for targeted DD
            window.fr_builder_lc_select = function() {
                new lc_select('.fr_lc_select', {
                    wrap_width : '100%',
                    addit_classes : ['lcslt-lcwp'],
                });
            };
            fr_builder_lc_select();



            ///////////////////////////////////////////



            // fixed submit position
            var fr_fixed_submit = function(btn_selector) {
                var $subj = $(btn_selector);
                if(!$subj.length) {return false;}

                var clone = $subj.clone().wrap("<div />").parent().html();

                setInterval(function() {

                    // if page has scrollers or scroll is far from bottom
                    if( 
                        $(document).height() > $(window).height() && 
                        $(window).scrollTop() > 300
                    ) {
                        if(!$('.lcwp_settings_fixed_submit').length) {	
                            $subj.after('<div class="lcwp_settings_fixed_submit fr_builder_fsb">'+ clone +'</div>');
                        }
                    }
                    else {
                        if($('.lcwp_settings_fixed_submit').length) {	
                            $('.lcwp_settings_fixed_submit').remove();
                        }
                    }
                }, 50);
            };
            fr_fixed_submit('#publish');
        });
    })(jQuery);
	</script>
     
    <?php
	return true;	
}








//////////////////////////
// SAVING METABOXES

function fr_faqs_meta_save($post_id) {
	if(isset($_POST['fr_faq_noncename']) || isset($_POST['fr_faq_choices']) || isset($_POST['fr_search_helper'])) {

		// authentication checks
		if (!wp_verify_nonce($_POST['fr_faq_noncename'], 'lcwp_nonce')) return $post_id;
		if (!current_user_can('edit_post', $post_id)) return $post_id;

		$field_keys = array('fr_faq_type', 'fr_sort_order', 'fr_search_helper', 'fr_init_question', 'fr_basic_faq_gallery', 'fr_basic_faq_kb', 'fr_faq_choices');
		
		foreach($field_keys as $key) {
			if(isset($_POST[$key])) {
				
				// try compressing the huge FAQ structure
				if($key == 'fr_faq_choices') {
					$_POST[$key] = fr_maybe_compress($_POST[$key]);	
				}
				
				update_post_meta($post_id, $key, $_POST[$key]);
			}
		}
	}

    return $post_id;
}
add_action('save_post', 'fr_faqs_meta_save');


